Struct amazon_sp_fba_inventory::models::granularity::Granularity
source · [−]pub struct Granularity {
pub granularity_type: Option<String>,
pub granularity_id: Option<String>,
}Expand description
Granularity : Describes a granularity at which inventory data can be aggregated. For example, if you use Marketplace granularity, the fulfillable quantity will reflect inventory that could be fulfilled in the given marketplace.
Fields
granularity_type: Option<String>The granularity type for the inventory aggregation level.
granularity_id: Option<String>The granularity ID for the specified granularity type. When granularityType is Marketplace, specify the marketplaceId.
Implementations
sourceimpl Granularity
impl Granularity
sourcepub fn new() -> Granularity
pub fn new() -> Granularity
Describes a granularity at which inventory data can be aggregated. For example, if you use Marketplace granularity, the fulfillable quantity will reflect inventory that could be fulfilled in the given marketplace.